[{"locale":"es"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula A"}},"key":"1D49C"},{"key":"212C","mappings":{"default":{"default":"script mayúscula B"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula C"}},"key":"1D49E"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula D"}},"key":"1D49F"},{"key":"2130","mappings":{"default":{"default":"script mayúscula E"}},"category":"Lu"},{"key":"2131","mappings":{"default":{"default":"script mayúscula F"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula G"}},"key":"1D4A2"},{"key":"210B","mappings":{"default":{"default":"script mayúscula H"}},"category":"Lu"},{"key":"2110","mappings":{"default":{"default":"script mayúscula I"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula J"}},"key":"1D4A5"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula K"}},"key":"1D4A6"},{"key":"2112","mappings":{"default":{"default":"script mayúscula L"}},"category":"Lu"},{"key":"2133","mappings":{"default":{"default":"script mayúscula M"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula N"}},"key":"1D4A9"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula O"}},"key":"1D4AA"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula P"}},"key":"1D4AB"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula Q"}},"key":"1D4AC"},{"key":"211B","mappings":{"default":{"default":"script mayúscula R"}},"category":"Lu"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula S"}},"key":"1D4AE"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula T"}},"key":"1D4AF"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula U"}},"key":"1D4B0"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula V"}},"key":"1D4B1"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula W"}},"key":"1D4B2"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula X"}},"key":"1D4B3"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula Y"}},"key":"1D4B4"},{"category":"Lu","mappings":{"default":{"default":"script mayúscula Z"}},"key":"1D4B5"},{"category":"Ll","mappings":{"default":{"default":"script a"}},"key":"1D4B6"},{"category":"Ll","mappings":{"default":{"default":"script b"}},"key":"1D4B7"},{"category":"Ll","mappings":{"default":{"default":"script c"}},"key":"1D4B8"},{"category":"Ll","mappings":{"default":{"default":"script d"}},"key":"1D4B9"},{"key":"212F","mappings":{"default":{"default":"script e"}},"category":"Ll"},{"category":"Ll","mappings":{"default":{"default":"script f"}},"key":"1D4BB"},{"key":"210A","mappings":{"default":{"default":"script g"}},"category":"Ll"},{"category":"Ll","mappings":{"default":{"default":"script h"}},"key":"1D4BD"},{"category":"Ll","mappings":{"default":{"default":"script i"}},"key":"1D4BE"},{"category":"Ll","mappings":{"default":{"default":"script j"}},"key":"1D4BF"},{"category":"Ll","mappings":{"default":{"default":"script k"}},"key":"1D4C0"},{"category":"Ll","mappings":{"default":{"default":"script l"}},"key":"1D4C1"},{"category":"Ll","mappings":{"default":{"default":"script m"}},"key":"1D4C2"},{"category":"Ll","mappings":{"default":{"default":"script n"}},"key":"1D4C3"},{"key":"2134","mappings":{"default":{"default":"script o"}},"category":"Ll"},{"category":"Ll","mappings":{"default":{"default":"script p"}},"key":"1D4C5"},{"category":"Ll","mappings":{"default":{"default":"script q"}},"key":"1D4C6"},{"category":"Ll","mappings":{"default":{"default":"script r"}},"key":"1D4C7"},{"category":"Ll","mappings":{"default":{"default":"script s"}},"key":"1D4C8"},{"category":"Ll","mappings":{"default":{"default":"script t"}},"key":"1D4C9"},{"category":"Ll","mappings":{"default":{"default":"script u"}},"key":"1D4CA"},{"category":"Ll","mappings":{"default":{"default":"script v"}},"key":"1D4CB"},{"category":"Ll","mappings":{"default":{"default":"script w"}},"key":"1D4CC"},{"category":"Ll","mappings":{"default":{"default":"script x"}},"key":"1D4CD"},{"category":"Ll","mappings":{"default":{"default":"script y"}},"key":"1D4CE"},{"category":"Ll","mappings":{"default":{"default":"script z"}},"key":"1D4CF"}]
